@@ -2,13 +2,14 @@ context("print_dust_methods")
 
 test_that("print_dust_console",
 {
+  skip_on_cran()
   fit <- lm(mpg ~ qsec + factor(am) + wt + factor(gear), data = mtcars)
   x <- dust(fit) %>% 
     sprinkle(rows = 2:4,
              cols = 2:4,
              bg = "black",
              bold = TRUE,
-             border_collapse = FALSE,
+             border_collapse = "collapse",
              border = c("left", "right"),
              border_thickness = 2,
              border_units = "px",
@@ -34,13 +35,14 @@ test_that("print_dust_console",
 
 test_that("print_dust_html",
 {
+  skip_on_cran()
   fit <- lm(mpg ~ qsec + factor(am) + wt + factor(gear), data = mtcars)
   x <- dust(fit) %>% 
     sprinkle(rows = 2:4,
              cols = 2:4,
              bg = "black",
              bold = TRUE,
-             border_collapse = FALSE,
+             border_collapse = "collapse",
              border = c("left", "right"),
              border_thickness = 2,
              border_units = "px",
@@ -67,7 +69,10 @@ test_that("print_dust_html",
 
 test_that("print_dust_html: correction for multiple cell merge",
 {
-  custom_head <- rbind(names(mtcars), Hmisc::label(mtcars)) %>%
+  skip_on_cran()
+  custom_head <- rbind(names(mtcars), 
+                       labelVector::get_label(mtcars,
+                                              names(mtcars))) %>%
     as.data.frame(stringsAsFactors = FALSE)
   
   custom_foot <- rbind(vapply(mtcars, mean, numeric(1)),
@@ -95,13 +100,14 @@ test_that("print_dust_html: correction for multiple cell merge",
 
 test_that("print_dust_markdown",
 {
+  skip_on_cran()
   fit <- lm(mpg ~ qsec + factor(am) + wt + factor(gear), data = mtcars)
   x <- dust(fit) %>% 
     sprinkle(rows = 2:4,
              cols = 2:4,
              bg = "black",
              bold = TRUE,
-             border_collapse = FALSE,
+             border_collapse = "collapse",
              border = c("left", "right"),
              border_thickness = 2,
              border_units = "px",
@@ -129,13 +135,14 @@ test_that("print_dust_markdown",
 
 test_that("print_dust_latex",
           {
+            skip_on_cran()
             fit <- lm(mpg ~ qsec + factor(am) + wt + factor(gear), data = mtcars)
             x <- dust(fit) %>% 
               sprinkle(rows = 2:4,
                        cols = 2:4,
                        bg = "black",
                        bold = TRUE,
-                       border_collapse = FALSE,
+                       border_collapse = "collapse",
                        border = c("left", "right"),
                        border_thickness = 2,
                        border_units = "px",
@@ -163,6 +170,7 @@ test_that("print_dust_latex",
 test_that(
   "missing values in LaTeX output - sanitization",
   {
+    skip_on_cran()
     DF <- head(mtcars)
     DF$mpg[c(1, 3, 4)] <- NA
     
@@ -177,6 +185,7 @@ test_that(
 test_that(
   "print_dust_latex does not output invalid -Inf width or height", 
   {
+    skip_on_cran()
     fit <- lm(mpg ~ qsec + factor(am) + wt + factor(gear), data = mtcars)
     x <- print_dust_latex(dust(fit))
     expect_false(grepl("-Inf", x))
@@ -186,6 +195,7 @@ test_that(
 test_that(
   "html tables with bookdown label",
   {
+    skip_on_cran()
     fit <- lm(mpg ~ qsec + factor(am) + wt + factor(gear), data = mtcars)
     x <- dust(fit,
               caption = "Table heading",
