@@ -14,6 +14,17 @@ test_that(
   }
 )
 
+test_that(
+  "Function succeeds when called on a dust_list object",
+  {
+    expect_silent(
+      dplyr::group_by(mtcars, am, vs) %>% 
+        dust(ungroup = FALSE) %>% 
+        sprinkle_tabcolsep(tabcolsep = 3)
+    )
+  }
+)
+
 # Functional Requirement 2 ------------------------------------------
 
 test_that(
